.. contents::



Utilities
##############

Service module (REST or WSDL)
===================================================================

.. automodule:: bioservices.services
    :members:
    :undoc-members:
    :synopsis: 

xmltools module
========================

.. automodule:: bioservices.xmltools
    :members:
    :undoc-members:
    :synopsis:



Services
#############

BioGrid
====================

.. automodule:: bioservices.biogrid
    :members:
    :undoc-members:
    :synopsis:

BioModels
====================

.. automodule:: bioservices.biomodels
    :members:
    :undoc-members:
    :synopsis:

ChEMBLdb
==========

.. automodule:: bioservices.chembldb
    :members:
    :undoc-members:
    :synopsis:

QuickGO
================

.. automodule:: bioservices.quickgo
    :members:
    :undoc-members:
    :synopsis: 

Kegg
===================================================================


.. automodule:: bioservices.kegg
    :members:
    :undoc-members:
    :synopsis:

NCBIblast
================

.. automodule:: bioservices.ncbiblast
    :members:
    :undoc-members:
    :synopsis:

PICR module
===================================================================

.. automodule:: bioservices.picr
    :members:
    :undoc-members:
    :synopsis:

PSICQUIC
================

.. automodule:: bioservices.psicquic
    :members:
    :undoc-members:
    :synopsis:

Rhea
==============

.. automodule:: bioservices.rhea
    :members:
    :undoc-members:
    :synopsis:

.. Reactome
.. =====================

.. .. automodule:: bioservices.reactome
    :members:
    :undoc-members:
    :synopsis:

Uniprot
===================================================================

.. automodule:: bioservices.uniprot
    :members:
    :undoc-members:
    :synopsis:

wsdbfetch
===================================================================

.. automodule:: bioservices.wsdbfetch
    :members:
    :undoc-members:
    :synopsis:

Wikipathway
===================================================================

.. automodule:: bioservices.wikipathway
    :members:
    :undoc-members:
    :synopsis:



